/*
             LUFA Library
     Copyright (C) Dean Camera, 2015.

  dean [at] fourwalledcubicle [dot] com
           www.lufa-lib.org
*/

/*
  Copyright 2015  Dean Camera (dean [at] fourwalledcubicle [dot] com)

  Permission to use, copy, modify, distribute, and sell this
  software and its documentation for any purpose is hereby granted
  without fee, provided that the above copyright notice appear in
  all copies and that both that the copyright notice and this
  permission notice and warranty disclaimer appear in supporting
  documentation, and that the name of the author not be used in
  advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.

  The author disclaims all warranties with regard to this
  software, including all implied warranties of merchantability
  and fitness.  In no event shall the author be liable for any
  special, indirect or consequential damages or any damages
  whatsoever resulting from loss of use, data or profits, whether
  in an action of contract, negligence or other tortious action,
  arising out of or in connection with the use or performance of
  this software.
*/

/** \file
 *
 *  Header file for USB2SerialMux.c.
 */

#ifndef _DUAL_VIRTUALSERIAL_H_
#define _DUAL_VIRTUALSERIAL_H_

  /* Includes: */
    #include <avr/io.h>
    #include <avr/wdt.h>
    #include <avr/power.h>
    #include <avr/interrupt.h>
    #include <avr/eeprom.h>

    #include <string.h>

    #include "Descriptors.h"

    #include "globals.h"

    #include "command_ctrl.h"

    #include <LUFA/Drivers/USB/USB.h>
    #include <LUFA/Platform/Platform.h>

    uint8_t error_mask = 0x00;

  /* UART definitions: */

    //#define UART_BAUD_RATE     115200
    #define OUTPUT_BUFFER_SIZE 100

    #include "uart/uart.h" // include after the definition

  /* Macros: */

    #define SET_ERR_MASK(m) error_mask = m

    /** Error mask, to indicate that the USB interface is not ready. */
    #define ERRMASK_USB_NOTREADY      (1 << 0)

    /** Error mask, to indicate that the USB interface is enumerating. */
    #define ERRMASK_USB_ENUMERATING  ((1 << 1) | (1 << 2))

    /** Error mask, to indicate that the USB interface is ready. */
    #define ERRMASK_USB_READY        ((1 << 1) | (1 << 3))

    /** Error mask, to indicate that an error has occurred in the USB interface. */
    #define ERRMASK_USB_ERROR        ((1 << 0) | (1 << 2))

  /* Function Prototypes: */
    void CDC1_Task(void);
    void CDC2_Task(void);
    void SetupHardware(void);

    void EVENT_USB_Device_Connect(void);
    void EVENT_USB_Device_Disconnect(void);
    void EVENT_USB_Device_ConfigurationChanged(void);
    void EVENT_USB_Device_ControlRequest(void);

    void USB_serialStreamWriteC(char*, uint16_t);

#endif

